==> flamerobin-0.7.2-src.tar.gz: flamerobin-0.7.2-src/src/sql/SqlStatement.h <==
/*
Copyright (c) 2004, 2005, 2006 The FlameRobin Development Team

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


  $Id: SqlStatement.h 1109 2006-05-13 14:19:47Z mbabuskov $

*/
//-----------------------------------------------------------------------------
#ifndef FR_SQL_STATEMENT_H
#define FR_SQL_STATEMENT_H

#include <vector>
#include <map>
#include "metadata/metadataitem.h"
#include "SqlTokenizer.h"
class Relation;
class Database;
//-----------------------------------------------------------------------------
typedef enum
{
    actNONE, actALTER, actCREATE, actCREATE_OR_ALTER, actDECLARE, actDROP,
    actRECREATE, actSET, actUPDATE, actGRANT
} SqlAction;
//-----------------------------------------------------------------------------
class TokenList
{
private:
    std::vector<SqlTokenType> tokensM;
public:
    size_t size() const;
    void add(const SqlTokenType& item);
    const SqlTokenType& operator[](const size_t& index) const;
};
//-----------------------------------------------------------------------------
class SqlStatement
{
public:
    SqlStatement(const wxString& sql, Database *db);

    bool isDDL() const;
    SqlAction getAction() const;
    bool actionIs(const SqlAction& act, NodeType nt = ntUnknown) const;
    NodeType getObjectType() const;
    MetadataItem* getObject();
    Identifier getIdentifier();
    wxString getName();
    wxString getFieldName();
    bool isAlterColumn() const;
    bool isDatatype() const;
    Relation* getCreateTriggerRelation();

protected:
    TokenList tokensM;
    size_t identifierTokenIndexM;
    std::map<int, wxString> tokenStringsM;

    MetadataItem *objectM;
    Database *databaseM;
    NodeType objectTypeM;
    SqlAction actionM;
    Identifier nameM;
    Identifier fieldNameM;  // table columns
    bool isAlterColumnM;
    bool isDatatypeM;
};
//-----------------------------------------------------------------------------
#endif

==> flamerobin-0.7.5-src.tar.gz: flamerobin-0.7.5-src/src/sql/SqlStatement.h <==
/*
Copyright (c) 2004, 2005, 2006 The FlameRobin Development Team

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


  $Id: SqlStatement.h 1210 2006-08-22 21:32:51Z mbabuskov $

*/
//-----------------------------------------------------------------------------
#ifndef FR_SQL_STATEMENT_H
#define FR_SQL_STATEMENT_H

#include <vector>
#include <map>
#include "metadata/metadataitem.h"
#include "SqlTokenizer.h"
class Relation;
class Database;
//-----------------------------------------------------------------------------
typedef enum
{
    actNONE, actALTER, actCREATE, actCREATE_OR_ALTER, actDECLARE, actDROP,
    actRECREATE, actSET, actUPDATE, actGRANT, actCOMMENT
} SqlAction;
//-----------------------------------------------------------------------------
class TokenList
{
private:
    std::vector<SqlTokenType> tokensM;
public:
    size_t size() const;
    void add(const SqlTokenType& item);
    const SqlTokenType& operator[](const size_t& index) const;
};
//-----------------------------------------------------------------------------
class SqlStatement
{
public:
    SqlStatement(const wxString& sql, Database *db);

    bool isDDL() const;
    SqlAction getAction() const;
    bool actionIs(const SqlAction& act, NodeType nt = ntUnknown) const;
    NodeType getObjectType() const;
    MetadataItem* getObject();
    Identifier getIdentifier();
    wxString getName();
    wxString getFieldName();
    bool isAlterColumn() const;
    bool isDatatype() const;
    Relation* getCreateTriggerRelation();

protected:
    TokenList tokensM;
    size_t identifierTokenIndexM;
    std::map<int, wxString> tokenStringsM;

    MetadataItem *objectM;
    Database *databaseM;
    NodeType objectTypeM;
    SqlAction actionM;
    Identifier nameM;
    Identifier fieldNameM;  // table columns
    bool isAlterColumnM;
    bool isDatatypeM;
};
//-----------------------------------------------------------------------------
#endif
